<?php

declare(strict_types=1);

namespace Pinpoint\TaxSwitch\ViewModel;

use Pinpoint\TaxSwitch\Api\ConfigHelperInterface;
use Pinpoint\TaxSwitch\Api\SwitchViewModelInterface;
use Pinpoint\TaxSwitch\Model\Catalog\Pricing\Price\TaxSwitchFinalPrice;
use Pinpoint\TaxSwitch\Model\Config\Source\TaxDisplay;

/**
 * Tax switcher view model
 */
class TaxSwitch implements SwitchViewModelInterface
{
    /**
     * @var string
     */
    public const PRICE_TYPE = TaxSwitchFinalPrice::PRICE_CODE;

    private const OPTION_LABEL_CLASSES = 'label_classes';
    private const OPTION_INPUT_ELEMENT_ID = 'input_element_id';

    /**
     * @var \Pinpoint\TaxSwitch\Api\ConfigHelperInterface
     */
    private $configHelper;

    /**
     * @var array
     */
    private $options;

    private $defaultOptions = [
        self::OPTION_LABEL_CLASSES => 'tax switch',
        self::OPTION_INPUT_ELEMENT_ID => 'tax_switch'
    ];


    /**
     * @param \Pinpoint\TaxSwitch\Api\ConfigHelperInterface $configHelper
     * @param array                                         $options
     */
    public function __construct(
        ConfigHelperInterface $configHelper,
        array $options = []
    ) {
        $this->configHelper = $configHelper;
        $this->options = array_merge_recursive($options, $this->defaultOptions);
    }

    /**
     * @return bool
     */
    public function isEnabled(): bool
    {
        return $this->configHelper->isEnabled();
    }

    /**
     * @inheritDoc
     */
    public function getLabelElementClasses(): string
    {
        return $this->options[self::OPTION_LABEL_CLASSES] ?? $this->defaultOptions[self::OPTION_LABEL_CLASSES];
    }

    /**
     * @inheritDoc
     */
    public function getInputElementId(): string
    {
        return $this->options[self::OPTION_INPUT_ELEMENT_ID] ?? $this->defaultOptions[self::OPTION_INPUT_ELEMENT_ID];
    }

    /**
     * @return string
     */
    public function getPriceTypeCode(): string
    {
        return self::PRICE_TYPE;
    }

    /**
     * @return int
     */
    public function getDefaultDisplayType(): int
    {
        return $this->configHelper->getDefaultDisplay();
    }

    /**
     * @inheritDoc
     */
    public function isInputElementChecked(): bool
    {
        return $this->getDefaultDisplayType() === TaxDisplay::DISPLAY_TYPE_INCLUDING_TAX;
    }
}
